//+------------------------------------------------------------------+
//|                                     DemoTradeEventProcessing.mq5 |
//|                        Copyright 2011, MetaQuotes Software Corp. |
//|                                              http://www.mql5.com |
//+------------------------------------------------------------------+
#property copyright "Copyright 2011, MetaQuotes Software Corp."
#property link      "http://www.mql5.com"
#property version   "1.00"

input    int days=7;            //     
int          orders;            //   
int          positions;         //   
int          deals;             //      
int          history_orders;    //      
bool         started=false;     //   
//---       
datetime     start;             //      
datetime     end;               //       
//+------------------------------------------------------------------+
//| Expert initialization function                                   |
//+------------------------------------------------------------------+
int OnInit()
  {
//---
   end=TimeCurrent();
   start=end-days*PeriodSeconds(PERIOD_D1);
   PrintFormat("   :  - %s,  - %s",
               TimeToString(start),TimeToString(end));
   InitCounters();
//---
   return(0);
  }
//+------------------------------------------------------------------+
//| Expert tick function                                             |
//+------------------------------------------------------------------+
void OnTick()
  {
//--- 
   if(started) SimpleTradeProcessor();
   else InitCounters();
  }
//+------------------------------------------------------------------+
//|     Trade                         |
//+------------------------------------------------------------------+
void OnTrade()
  {
   if(started) SimpleTradeProcessor();
   else InitCounters();
  }
//+------------------------------------------------------------------+
//|    ,                  |
//+------------------------------------------------------------------+
void InitCounters()
  {
   ResetLastError();
//---   
   bool selected=HistorySelect(start,end);
   if(!selected)
     {
      PrintFormat("%s.        %s  %s.  : %d",
                  __FUNCTION__,TimeToString(start),TimeToString(end),GetLastError());
      return;
     }
//---   
   orders=OrdersTotal();
   positions=PositionsTotal();
   deals=HistoryDealsTotal();
   history_orders=HistoryOrdersTotal();
   started=true;
   Print(" ,      ");
  }
//+------------------------------------------------------------------+
//|               |
//+------------------------------------------------------------------+
void SimpleTradeProcessor()
  {
   end=TimeCurrent();
   ResetLastError();
//---   
   bool selected=HistorySelect(start,end);
   if(!selected)
     {
      PrintFormat("%s.        %s  %s.  : %d",
                  __FUNCTION__,TimeToString(start),TimeToString(end),GetLastError());
      return;
     }

//---   
   int curr_orders=OrdersTotal();
   int curr_positions=PositionsTotal();
   int curr_deals=HistoryDealsTotal();
   int curr_history_orders=HistoryOrdersTotal();

//---      
   if(curr_orders!=orders)
     {
      //---    
      PrintFormat("  .  %d,  %d",
                  orders,curr_orders);
     /*
        -      
     */
      //---  
      orders=curr_orders;
     }

//---     
   if(curr_positions!=positions)
     {
      //---    
      PrintFormat("  .  %d,  %d",
                  positions,curr_positions);
      /*
        -       
      */
      //---  
      positions=curr_positions;
     }

//---        
   if(curr_deals!=deals)
     {
      //---       
      PrintFormat("  .  %d,  %d",
                  deals,curr_deals);
      /*
        -       
      */
      //---  
      deals=curr_deals;
     }

//---         
   if(curr_history_orders!=history_orders)
     {
      //---        
      PrintFormat("    .  %d,  %d",
                  history_orders,curr_history_orders);
     /*
        -           
      */
     //---  
     history_orders=curr_history_orders;
     }
//---           
   CheckStartDateInTradeHistory();
  }
//+------------------------------------------------------------------+
//|                   |
//+------------------------------------------------------------------+
void CheckStartDateInTradeHistory()
  {
//---  ,       
   datetime curr_start=TimeCurrent()-days*PeriodSeconds(PERIOD_D1);
//--- ,        , 
//---   1    
   if(curr_start-start>PeriodSeconds(PERIOD_D1))
     {
      //---         
      start=curr_start;
      PrintFormat("     :  => %s",
                  TimeToString(start));

      //---        
      HistorySelect(start,end);

      //---  -        
      history_orders=HistoryOrdersTotal();
      deals=HistoryDealsTotal();
     }
  }
//+------------------------------------------------------------------+
